/*
 * Copyright (c) 1994 Cygnus Support.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms are permitted
 * provided that the above copyright notice and this paragraph are
 * duplicated in all such forms and that any documentation,
 * and/or other materials related to such
 * distribution and use acknowledge that the software was developed
 * at Cygnus Support, Inc.  Cygnus Support, Inc. may not be used to
 * endorse or promote products derived from this software without
 * specific prior written permission.
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */
#include "test.h"
 one_line_type ynf_vec[] = {
{30, 0,123,__LINE__, 0xbfffab42, 0x00000000, 0x00000000, 0x00000000, 0x3fa99999, 0x9999999a},	/* -1.97931=f(0, 0.05)*/
{30, 0,123,__LINE__, 0xc0299467, 0xc0000000, 0x3ff00000, 0x00000000, 0x3fa99999, 0x9999999a},	/* -12.7899=f(1, 0.05)*/
{30, 0,123,__LINE__, 0xc07fd9d6, 0x60000000, 0x40000000, 0x00000000, 0x3fa99999, 0x9999999a},	/* -509.615=f(2, 0.05)*/
{30, 0,123,__LINE__, 0xc0e3e68c, 0xc0000000, 0x40080000, 0x00000000, 0x3fa99999, 0x9999999a},	/* -40756.4=f(3, 0.05)*/
{30, 0,123,__LINE__, 0xc152a7a4, 0x80000000, 0x40100000, 0x00000000, 0x3fa99999, 0x9999999a},	/* -4.89026e+06=f(4, 0.05)*/
{30, 0,123,__LINE__, 0xbff88c3d, 0xc0000000, 0x00000000, 0x00000000, 0x3fb99999, 0x9999999a},	/* -1.53424=f(0, 0.1)*/
{30, 0,123,__LINE__, 0xc019d5f7, 0x20000000, 0x3ff00000, 0x00000000, 0x3fb99999, 0x9999999a},	/* -6.45895=f(1, 0.1)*/
{30, 0,123,__LINE__, 0xc05fe944, 0x20000000, 0x40000000, 0x00000000, 0x3fb99999, 0x9999999a},	/* -127.645=f(2, 0.1)*/
{30, 0,123,__LINE__, 0xc0b3eb55, 0x20000000, 0x40080000, 0x00000000, 0x3fb99999, 0x9999999a},	/* -5099.33=f(3, 0.1)*/
{30, 0,123,__LINE__, 0xc112aaa1, 0x40000000, 0x40100000, 0x00000000, 0x3fb99999, 0x9999999a},	/* -305832=f(4, 0.1)*/
{30, 0,123,__LINE__, 0xbff45519, 0xa0000000, 0x00000000, 0x00000000, 0x3fc33333, 0x33333334},	/* -1.27078=f(0, 0.15)*/
{30, 0,123,__LINE__, 0xc0117469, 0x60000000, 0x3ff00000, 0x00000000, 0x3fc33333, 0x33333334},	/* -4.36368=f(1, 0.15)*/
{30, 0,123,__LINE__, 0xc04c74b1, 0x60000000, 0x40000000, 0x00000000, 0x3fc33333, 0x33333334},	/* -56.9117=f(2, 0.15)*/
{30, 0,123,__LINE__, 0xc097a51f, 0x60000000, 0x40080000, 0x00000000, 0x3fc33333, 0x33333334},	/* -1513.28=f(3, 0.15)*/
{30, 0,123,__LINE__, 0xc0ed874a, 0x00000000, 0x40100000, 0x00000000, 0x3fc33333, 0x33333334},	/* -60474.3=f(4, 0.15)*/
{30, 0,123,__LINE__, 0xbff14c35, 0x20000000, 0x00000000, 0x00000000, 0x3fc99999, 0x9999999a},	/* -1.08111=f(0, 0.2)*/
{30, 0,123,__LINE__, 0xc00a9731, 0x80000000, 0x3ff00000, 0x00000000, 0x3fc99999, 0x9999999a},	/* -3.32382=f(1, 0.2)*/
{30, 0,123,__LINE__, 0xc040141d, 0x40000000, 0x40000000, 0x00000000, 0x3fc99999, 0x9999999a},	/* -32.1571=f(2, 0.2)*/
{30, 0,123,__LINE__, 0xc083fe8d, 0x60000000, 0x40080000, 0x00000000, 0x3fc99999, 0x9999999a},	/* -639.819=f(3, 0.2)*/
{30, 0,123,__LINE__, 0xc0d2b69a, 0x80000000, 0x40100000, 0x00000000, 0x3fc99999, 0x9999999a},	/* -19162.4=f(4, 0.2)*/
{30, 0,123,__LINE__, 0xbfedcf72, 0x20000000, 0x00000000, 0x00000000, 0x3fd00000, 0x00000000},	/* -0.931573=f(0, 0.25)*/
{30, 0,123,__LINE__, 0xc005a201, 0xe0000000, 0x3ff00000, 0x00000000, 0x3fd00000, 0x00000000},	/* -2.70411=f(1, 0.25)*/
{30, 0,123,__LINE__, 0xc034b386, 0x40000000, 0x40000000, 0x00000000, 0x3fd00000, 0x00000000},	/* -20.7013=f(2, 0.25)*/
{30, 0,123,__LINE__, 0xc0748842, 0x40000000, 0x40080000, 0x00000000, 0x3fd00000, 0x00000000},	/* -328.516=f(3, 0.25)*/
{30, 0,123,__LINE__, 0xc0beb7af, 0xe0000000, 0x40100000, 0x00000000, 0x3fd00000, 0x00000000},	/* -7863.69=f(4, 0.25)*/
{30, 0,123,__LINE__, 0xbfe9d52f, 0x60000000, 0x00000000, 0x00000000, 0x3fd33333, 0x33333333},	/* -0.807274=f(0, 0.3)*/
{30, 0,123,__LINE__, 0xc0025847, 0x60000000, 0x3ff00000, 0x00000000, 0x3fd33333, 0x33333333},	/* -2.2931=f(1, 0.3)*/
{30, 0,123,__LINE__, 0xc02cf5ce, 0xa0000000, 0x40000000, 0x00000000, 0x3fd33333, 0x33333333},	/* -14.4801=f(2, 0.3)*/
{30, 0,123,__LINE__, 0xc067d8cb, 0x00000000, 0x40080000, 0x00000000, 0x3fd33333, 0x33333333},	/* -190.775=f(3, 0.3)*/
{30, 0,123,__LINE__, 0xc0adb207, 0xe0000000, 0x40100000, 0x00000000, 0x3fd33333, 0x33333333},	/* -3801.02=f(4, 0.3)*/
{30, 0,123,__LINE__, 0xbfe668f8, 0x00000000, 0x00000000, 0x00000000, 0x3fd66666, 0x66666666},	/* -0.700314=f(0, 0.35)*/
{30, 0,123,__LINE__, 0xc00000cf, 0xa0000000, 0x3ff00000, 0x00000000, 0x3fd66666, 0x66666666},	/* -2.0004=f(1, 0.35)*/
{30, 0,123,__LINE__, 0xc0257606, 0xe0000000, 0x40000000, 0x00000000, 0x3fd66666, 0x66666666},	/* -10.7305=f(2, 0.35)*/
{30, 0,123,__LINE__, 0xc05e2895, 0xa0000000, 0x40080000, 0x00000000, 0x3fd66666, 0x66666666},	/* -120.634=f(3, 0.35)*/
{30, 0,123,__LINE__, 0xc0a01291, 0x00000000, 0x40100000, 0x00000000, 0x3fd66666, 0x66666666},	/* -2057.28=f(4, 0.35)*/
{30, 0,123,__LINE__, 0xbfe3648d, 0x80000000, 0x00000000, 0x00000000, 0x3fd99999, 0x99999999},	/* -0.606025=f(0, 0.4)*/
{30, 0,123,__LINE__, 0xbffc7e73, 0xa0000000, 0x3ff00000, 0x00000000, 0x3fd99999, 0x99999999},	/* -1.78087=f(1, 0.4)*/
{30, 0,123,__LINE__, 0xc02098bf, 0x60000000, 0x40000000, 0x00000000, 0x3fd99999, 0x99999999},	/* -8.29834=f(2, 0.4)*/
{30, 0,123,__LINE__, 0xc0544cf5, 0x60000000, 0x40080000, 0x00000000, 0x3fd99999, 0x99999999},	/* -81.2025=f(3, 0.4)*/
{30, 0,123,__LINE__, 0xc092e6f4, 0x80000000, 0x40100000, 0x00000000, 0x3fd99999, 0x99999999},	/* -1209.74=f(4, 0.4)*/
{30, 0,123,__LINE__, 0xbfe0af8a, 0xc0000000, 0x00000000, 0x00000000, 0x3fdccccc, 0xcccccccc},	/* -0.521428=f(0, 0.45)*/
{30, 0,123,__LINE__, 0xbff9c0b2, 0x40000000, 0x3ff00000, 0x00000000, 0x3fdccccc, 0xcccccccc},	/* -1.60954=f(1, 0.45)*/
{30, 0,123,__LINE__, 0xc01a8746, 0x80000000, 0x40000000, 0x00000000, 0x3fdccccc, 0xcccccccc},	/* -6.6321=f(2, 0.45)*/
{30, 0,123,__LINE__, 0xc04cabd7, 0x00000000, 0x40080000, 0x00000000, 0x3fdccccc, 0xcccccccc},	/* -57.3425=f(3, 0.45)*/
{30, 0,123,__LINE__, 0xc087af7a, 0x00000000, 0x40100000, 0x00000000, 0x3fdccccc, 0xcccccccc},	/* -757.935=f(4, 0.45)*/
{30, 0,123,__LINE__, 0xbfdc72fe, 0xa0000000, 0x00000000, 0x00000000, 0x3fdfffff, 0xffffffff},	/* -0.444519=f(0, 0.5)*/
{30, 0,123,__LINE__, 0xbff78b26, 0xa0000000, 0x3ff00000, 0x00000000, 0x3fdfffff, 0xffffffff},	/* -1.47147=f(1, 0.5)*/
{30, 0,123,__LINE__, 0xc015c3f6, 0xc0000000, 0x40000000, 0x00000000, 0x3fdfffff, 0xffffffff},	/* -5.44137=f(2, 0.5)*/
{30, 0,123,__LINE__, 0xc045079d, 0x80000000, 0x40080000, 0x00000000, 0x3fdfffff, 0xffffffff},	/* -42.0595=f(3, 0.5)*/
{30, 0,123,__LINE__, 0xc07f345c, 0x60000000, 0x40100000, 0x00000000, 0x3fdfffff, 0xffffffff},	/* -499.273=f(4, 0.5)*/
{30, 0,123,__LINE__, 0xbfd7edc1, 0x80000000, 0x00000000, 0x00000000, 0x3fe19999, 0x99999999},	/* -0.373886=f(0, 0.55)*/
{30, 0,123,__LINE__, 0xbff5b705, 0x40000000, 0x3ff00000, 0x00000000, 0x3fe19999, 0x99999999},	/* -1.35718=f(1, 0.55)*/
{30, 0,123,__LINE__, 0xc0123ecb, 0x80000000, 0x40000000, 0x00000000, 0x3fe19999, 0x99999999},	/* -4.56132=f(2, 0.55)*/
{30, 0,123,__LINE__, 0xc03fd0ea, 0x60000000, 0x40080000, 0x00000000, 0x3fe19999, 0x99999999},	/* -31.8161=f(3, 0.55)*/
{30, 0,123,__LINE__, 0xc075685e, 0xc0000000, 0x40100000, 0x00000000, 0x3fe19999, 0x99999999},	/* -342.523=f(4, 0.55)*/
{30, 0,123,__LINE__, 0xbfd3bea0, 0x00000000, 0x00000000, 0x00000000, 0x3fe33333, 0x33333333},	/* -0.30851=f(0, 0.6)*/
{30, 0,123,__LINE__, 0xbff42a90, 0x00000000, 0x3ff00000, 0x00000000, 0x3fe33333, 0x33333333},	/* -1.26039=f(1, 0.6)*/
{30, 0,123,__LINE__, 0xc00f2471, 0x40000000, 0x40000000, 0x00000000, 0x3fe33333, 0x33333333},	/* -3.89279=f(2, 0.6)*/
{30, 0,123,__LINE__, 0xc038b10a, 0xa0000000, 0x40080000, 0x00000000, 0x3fe33333, 0x33333333},	/* -24.6916=f(3, 0.6)*/
{30, 0,123,__LINE__, 0xc06e60bb, 0x60000000, 0x40100000, 0x00000000, 0x3fe33333, 0x33333333},	/* -243.023=f(4, 0.6)*/
{30, 0,123,__LINE__, 0xbfcfb24a, 0xc0000000, 0x00000000, 0x00000000, 0x3fe4cccc, 0xcccccccd},	/* -0.247629=f(0, 0.65)*/
{30, 0,123,__LINE__, 0xbff2d40d, 0x60000000, 0x3ff00000, 0x00000000, 0x3fe4cccc, 0xcccccccd},	/* -1.17677=f(1, 0.65)*/
{30, 0,123,__LINE__, 0xc00afc52, 0xa0000000, 0x40000000, 0x00000000, 0x3fe4cccc, 0xcccccccd},	/* -3.3732=f(2, 0.65)*/
{30, 0,123,__LINE__, 0xc03394d7, 0x40000000, 0x40080000, 0x00000000, 0x3fe4cccc, 0xcccccccd},	/* -19.5814=f(3, 0.65)*/
{30, 0,123,__LINE__, 0xc0662c1a, 0xe0000000, 0x40100000, 0x00000000, 0x3fe4cccc, 0xcccccccd},	/* -177.378=f(4, 0.65)*/
{30, 0,123,__LINE__, 0xbfc867b5, 0x80000000, 0x00000000, 0x00000000, 0x3fe66666, 0x66666667},	/* -0.190665=f(0, 0.7)*/
{30, 0,123,__LINE__, 0xbff1a6e9, 0x60000000, 0x3ff00000, 0x00000000, 0x3fe66666, 0x66666667},	/* -1.10325=f(1, 0.7)*/
{30, 0,123,__LINE__, 0xc007b11b, 0x40000000, 0x40000000, 0x00000000, 0x3fe66666, 0x66666667},	/* -2.96148=f(2, 0.7)*/
{30, 0,123,__LINE__, 0xc02fa392, 0xe0000000, 0x40080000, 0x00000000, 0x3fe66666, 0x66666667},	/* -15.8195=f(3, 0.7)*/
{30, 0,123,__LINE__, 0xc060944a, 0x40000000, 0x40100000, 0x00000000, 0x3fe66666, 0x66666667},	/* -132.634=f(4, 0.7)*/
{30, 0,123,__LINE__, 0xbfc18ee0, 0xa0000000, 0x00000000, 0x00000000, 0x3fe80000, 0x00000001},	/* -0.137173=f(0, 0.75)*/
{30, 0,123,__LINE__, 0xbff099fc, 0xc0000000, 0x3ff00000, 0x00000000, 0x3fe80000, 0x00000001},	/* -1.03759=f(1, 0.75)*/
{30, 0,123,__LINE__, 0xc00509b8, 0x40000000, 0x40000000, 0x00000000, 0x3fe80000, 0x00000001},	/* -2.62975=f(2, 0.75)*/
{30, 0,123,__LINE__, 0xc029f9b6, 0x20000000, 0x40080000, 0x00000000, 0x3fe80000, 0x00000001},	/* -12.9877=f(3, 0.75)*/
{30, 0,123,__LINE__, 0xc0595168, 0x60000000, 0x40100000, 0x00000000, 0x3fe80000, 0x00000001},	/* -101.272=f(4, 0.75)*/
{30, 0,123,__LINE__, 0xbfb638ac, 0x60000000, 0x00000000, 0x00000000, 0x3fe99999, 0x9999999b},	/* -0.0868023=f(0, 0.8)*/
{30, 0,123,__LINE__, 0xbfef4cf4, 0xe0000000, 0x3ff00000, 0x00000000, 0x3fe99999, 0x9999999b},	/* -0.978144=f(1, 0.8)*/
{30, 0,123,__LINE__, 0xc002de53, 0xa0000000, 0x40000000, 0x00000000, 0x3fe99999, 0x9999999b},	/* -2.35856=f(2, 0.8)*/
{30, 0,123,__LINE__, 0xc025a119, 0x40000000, 0x40080000, 0x00000000, 0x3fe99999, 0x9999999b},	/* -10.8146=f(3, 0.8)*/
{30, 0,123,__LINE__, 0xc053b015, 0x00000000, 0x40100000, 0x00000000, 0x3fe99999, 0x9999999b},	/* -78.7513=f(4, 0.8)*/
{30, 0,123,__LINE__, 0xbfa41bfc, 0x00000000, 0x00000000, 0x00000000, 0x3feb3333, 0x33333335},	/* -0.039276=f(0, 0.85)*/
{30, 0,123,__LINE__, 0xbfed8e7b, 0x60000000, 0x3ff00000, 0x00000000, 0x3feb3333, 0x33333335},	/* -0.923643=f(1, 0.85)*/
{30, 0,123,__LINE__, 0xc001126f, 0x40000000, 0x40000000, 0x00000000, 0x3feb3333, 0x33333335},	/* -2.134=f(2, 0.85)*/
{30, 0,123,__LINE__, 0xc0223cc8, 0x40000000, 0x40080000, 0x00000000, 0x3feb3333, 0x33333335},	/* -9.11872=f(3, 0.85)*/
{30, 0,123,__LINE__, 0xc04f1de0, 0x00000000, 0x40100000, 0x00000000, 0x3feb3333, 0x33333335},	/* -62.2334=f(4, 0.85)*/
{30, 0,123,__LINE__, 0xbfebf0a7, 0x20000000, 0x3ff00000, 0x00000000, 0x3feccccc, 0xcccccccf},	/* -0.873127=f(1, 0.9)*/
{30, 0,123,__LINE__, 0xbfff2272, 0x20000000, 0x40000000, 0x00000000, 0x3feccccc, 0xcccccccf},	/* -1.94591=f(2, 0.9)*/
{30, 0,123,__LINE__, 0xc01f19f8, 0x40000000, 0x40080000, 0x00000000, 0x3feccccc, 0xcccccccf},	/* -7.77536=f(3, 0.9)*/
{30, 0,123,__LINE__, 0xc048f1e6, 0x00000000, 0x40100000, 0x00000000, 0x3feccccc, 0xcccccccf},	/* -49.8898=f(4, 0.9)*/
{30, 0,123,__LINE__, 0x3fa89f50, 0x20000000, 0x00000000, 0x00000000, 0x3fee6666, 0x66666669},	/* 0.0480905=f(0, 0.95)*/
{30, 0,123,__LINE__, 0xbfea6d54, 0xa0000000, 0x3ff00000, 0x00000000, 0x3fee6666, 0x66666669},	/* -0.825846=f(1, 0.95)*/
{30, 0,123,__LINE__, 0xbffc9661, 0x20000000, 0x40000000, 0x00000000, 0x3fee6666, 0x66666669},	/* -1.78671=f(2, 0.95)*/
{30, 0,123,__LINE__, 0xc01ac9e4, 0x20000000, 0x40080000, 0x00000000, 0x3fee6666, 0x66666669},	/* -6.69716=f(3, 0.95)*/
{30, 0,123,__LINE__, 0xc044416c, 0xe0000000, 0x40100000, 0x00000000, 0x3fee6666, 0x66666669},	/* -40.5111=f(4, 0.95)*/
{30, 0,123,__LINE__, 0x3fb69802, 0x20000000, 0x00000000, 0x00000000, 0x3ff00000, 0x00000001},	/* 0.088257=f(0, 1)*/
{30, 0,123,__LINE__, 0xbfe8ffb2, 0x00000000, 0x3ff00000, 0x00000000, 0x3ff00000, 0x00000001},	/* -0.781213=f(1, 1)*/
{30, 0,123,__LINE__, 0xbffa6932, 0x20000000, 0x40000000, 0x00000000, 0x3ff00000, 0x00000001},	/* -1.65068=f(2, 1)*/
{30, 0,123,__LINE__, 0xc017493b, 0xe0000000, 0x40080000, 0x00000000, 0x3ff00000, 0x00000001},	/* -5.82152=f(3, 1)*/
{30, 0,123,__LINE__, 0xc040a3a3, 0x60000000, 0x40100000, 0x00000000, 0x3ff00000, 0x00000001},	/* -33.2784=f(4, 1)*/
{30, 0,123,__LINE__, 0x3fc028e5, 0x40000000, 0x00000000, 0x00000000, 0x3ff0cccc, 0xccccccce},	/* 0.126248=f(0, 1.05)*/
{30, 0,123,__LINE__, 0xbfe7a3ee, 0x60000000, 0x3ff00000, 0x00000000, 0x3ff0cccc, 0xccccccce},	/* -0.738761=f(1, 1.05)*/
{30, 0,123,__LINE__, 0xbff888db, 0x20000000, 0x40000000, 0x00000000, 0x3ff0cccc, 0xccccccce},	/* -1.53341=f(2, 1.05)*/
{30, 0,123,__LINE__, 0xc0146946, 0xc0000000, 0x40080000, 0x00000000, 0x3ff0cccc, 0xccccccce},	/* -5.10281=f(3, 1.05)*/
{30, 0,123,__LINE__, 0xc03ba020, 0xa0000000, 0x40100000, 0x00000000, 0x3ff0cccc, 0xccccccce},	/* -27.6255=f(4, 1.05)*/
{30, 0,123,__LINE__, 0x3fc4c1c3, 0xa0000000, 0x00000000, 0x00000000, 0x3ff19999, 0x9999999b},	/* 0.162163=f(0, 1.1)*/
{30, 0,123,__LINE__, 0xbfe656fe, 0xc0000000, 0x3ff00000, 0x00000000, 0x3ff19999, 0x9999999b},	/* -0.69812=f(1, 1.1)*/
{30, 0,123,__LINE__, 0xbff6e74e, 0x80000000, 0x40000000, 0x00000000, 0x3ff19999, 0x9999999b},	/* -1.43147=f(2, 1.1)*/
{30, 0,123,__LINE__, 0xc0120767, 0x80000000, 0x40080000, 0x00000000, 0x3ff19999, 0x9999999b},	/* -4.50723=f(3, 1.1)*/
{30, 0,123,__LINE__, 0xc0372746, 0xc0000000, 0x40100000, 0x00000000, 0x3ff19999, 0x9999999b},	/* -23.1534=f(4, 1.1)*/
{30, 0,123,__LINE__, 0x3fc91951, 0xc0000000, 0x00000000, 0x00000000, 0x3ff26666, 0x66666668},	/* 0.196085=f(0, 1.15)*/
{30, 0,123,__LINE__, 0xbfe51674, 0x20000000, 0x3ff00000, 0x00000000, 0x3ff26666, 0x66666668},	/* -0.658991=f(1, 1.15)*/
{30, 0,123,__LINE__, 0xbff57979, 0x00000000, 0x40000000, 0x00000000, 0x3ff26666, 0x66666668},	/* -1.34216=f(2, 1.15)*/
{30, 0,123,__LINE__, 0xc010099a, 0xc0000000, 0x40080000, 0x00000000, 0x3ff26666, 0x66666668},	/* -4.00938=f(3, 1.15)*/
{30, 0,123,__LINE__, 0xc033938b, 0x60000000, 0x40100000, 0x00000000, 0x3ff26666, 0x66666668},	/* -19.5763=f(4, 1.15)*/
{30, 0,123,__LINE__, 0x3fcd31d7, 0x40000000, 0x00000000, 0x00000000, 0x3ff33333, 0x33333335},	/* 0.228084=f(0, 1.2)*/
{30, 0,123,__LINE__, 0xbfe3e059, 0x40000000, 0x3ff00000, 0x00000000, 0x3ff33333, 0x33333335},	/* -0.621136=f(1, 1.2)*/
{30, 0,123,__LINE__, 0xbff43685, 0x40000000, 0x40000000, 0x00000000, 0x3ff33333, 0x33333335},	/* -1.26331=f(2, 1.2)*/
{30, 0,123,__LINE__, 0xc00cb81d, 0x00000000, 0x40080000, 0x00000000, 0x3ff33333, 0x33333335},	/* -3.5899=f(3, 1.2)*/
{30, 0,123,__LINE__, 0xc030afa9, 0xc0000000, 0x40100000, 0x00000000, 0x3ff33333, 0x33333335},	/* -16.6862=f(4, 1.2)*/
{30, 0,123,__LINE__, 0x3fd086a0, 0x00000000, 0x00000000, 0x00000000, 0x3ff40000, 0x00000002},	/* 0.258217=f(0, 1.25)*/
{30, 0,123,__LINE__, 0xbfe2b31c, 0x20000000, 0x3ff00000, 0x00000000, 0x3ff40000, 0x00000002},	/* -0.584364=f(1, 1.25)*/
{30, 0,123,__LINE__, 0xbff31758, 0x20000000, 0x40000000, 0x00000000, 0x3ff40000, 0x00000002},	/* -1.1932=f(2, 1.25)*/
{30, 0,123,__LINE__, 0xc009def9, 0x60000000, 0x40080000, 0x00000000, 0x3ff40000, 0x00000002},	/* -3.23387=f(3, 1.25)*/
{30, 0,123,__LINE__, 0xc02ca8a6, 0x60000000, 0x40100000, 0x00000000, 0x3ff40000, 0x00000002},	/* -14.3294=f(4, 1.25)*/
{30, 0,123,__LINE__, 0x3fd25698, 0x40000000, 0x00000000, 0x00000000, 0x3ff4cccc, 0xcccccccf},	/* 0.286535=f(0, 1.3)*/
{30, 0,123,__LINE__, 0xbfe18d79, 0x40000000, 0x3ff00000, 0x00000000, 0x3ff4cccc, 0xcccccccf},	/* -0.54852=f(1, 1.3)*/
{30, 0,123,__LINE__, 0xbff2162a, 0xc0000000, 0x40000000, 0x00000000, 0x3ff4cccc, 0xcccccccf},	/* -1.13041=f(2, 1.3)*/
{30, 0,123,__LINE__, 0xc0076ff7, 0x40000000, 0x40080000, 0x00000000, 0x3ff4cccc, 0xcccccccf},	/* -2.92967=f(3, 1.3)*/
{30, 0,123,__LINE__, 0xc028c844, 0x60000000, 0x40100000, 0x00000000, 0x3ff4cccc, 0xcccccccf},	/* -12.3911=f(4, 1.3)*/
{30, 0,123,__LINE__, 0x3fd4098a, 0x00000000, 0x00000000, 0x00000000, 0x3ff59999, 0x9999999c},	/* 0.313082=f(0, 1.35)*/
{30, 0,123,__LINE__, 0xbfe06e6d, 0xc0000000, 0x3ff00000, 0x00000000, 0x3ff59999, 0x9999999c},	/* -0.51348=f(1, 1.35)*/
{30, 0,123,__LINE__, 0xbff12e42, 0x00000000, 0x40000000, 0x00000000, 0x3ff59999, 0x9999999c},	/* -1.07379=f(2, 1.35)*/
{30, 0,123,__LINE__, 0xc0055854, 0x80000000, 0x40080000, 0x00000000, 0x3ff59999, 0x9999999c},	/* -2.66813=f(3, 1.35)*/
{30, 0,123,__LINE__, 0xc02591b2, 0x00000000, 0x40100000, 0x00000000, 0x3ff59999, 0x9999999c},	/* -10.7846=f(4, 1.35)*/
{30, 0,123,__LINE__, 0x3fd5a012, 0xc0000000, 0x00000000, 0x00000000, 0x3ff66666, 0x66666669},	/* 0.337895=f(0, 1.4)*/
{30, 0,123,__LINE__, 0xbfdeaa58, 0x20000000, 0x3ff00000, 0x00000000, 0x3ff66666, 0x66666669},	/* -0.479147=f(1, 1.4)*/
{30, 0,123,__LINE__, 0xbff05bb6, 0x80000000, 0x40000000, 0x00000000, 0x3ff66666, 0x66666669},	/* -1.02239=f(2, 1.4)*/
{30, 0,123,__LINE__, 0xc0038927, 0x80000000, 0x40080000, 0x00000000, 0x3ff66666, 0x66666669},	/* -2.44197=f(3, 1.4)*/
{30, 0,123,__LINE__, 0xc022e2ea, 0x60000000, 0x40100000, 0x00000000, 0x3ff66666, 0x66666669},	/* -9.44319=f(4, 1.4)*/
{30, 0,123,__LINE__, 0x3fd71abe, 0xe0000000, 0x00000000, 0x00000000, 0x3ff73333, 0x33333336},	/* 0.361007=f(0, 1.45)*/
{30, 0,123,__LINE__, 0xbfdc8223, 0xc0000000, 0x3ff00000, 0x00000000, 0x3ff73333, 0x33333336},	/* -0.445443=f(1, 1.45)*/
{30, 0,123,__LINE__, 0xbfef3692, 0x80000000, 0x40000000, 0x00000000, 0x3ff73333, 0x33333336},	/* -0.975412=f(2, 1.45)*/
{30, 0,123,__LINE__, 0xc001f678, 0xc0000000, 0x40080000, 0x00000000, 0x3ff73333, 0x33333336},	/* -2.24535=f(3, 1.45)*/
{30, 0,123,__LINE__, 0xc020a1a1, 0x00000000, 0x40100000, 0x00000000, 0x3ff73333, 0x33333336},	/* -8.31568=f(4, 1.45)*/
{30, 0,123,__LINE__, 0x3fd87a0b, 0x00000000, 0x00000000, 0x00000000, 0x3ff80000, 0x00000003},	/* 0.382449=f(0, 1.5)*/
{30, 0,123,__LINE__, 0xbfda6343, 0xc0000000, 0x3ff00000, 0x00000000, 0x3ff80000, 0x00000003},	/* -0.412309=f(1, 1.5)*/
{30, 0,123,__LINE__, 0xbfedd488, 0x00000000, 0x40000000, 0x00000000, 0x3ff80000, 0x00000003},	/* -0.932194=f(2, 1.5)*/
{30, 0,123,__LINE__, 0xc000969c, 0xe0000000, 0x40080000, 0x00000000, 0x3ff80000, 0x00000003},	/* -2.07354=f(3, 1.5)*/
{30, 0,123,__LINE__, 0xc01d72a8, 0xc0000000, 0x40100000, 0x00000000, 0x3ff80000, 0x00000003},	/* -7.36197=f(4, 1.5)*/
{30, 0,123,__LINE__, 0x3fd9be6a, 0x00000000, 0x00000000, 0x00000000, 0x3ff8cccc, 0xccccccd0},	/* 0.402247=f(0, 1.55)*/
{30, 0,123,__LINE__, 0xbfd84cf9, 0x00000000, 0x3ff00000, 0x00000000, 0x3ff8cccc, 0xccccccd0},	/* -0.379698=f(1, 1.55)*/
{30, 0,123,__LINE__, 0xbfec8cbc, 0xe0000000, 0x40000000, 0x00000000, 0x3ff8cccc, 0xccccccd0},	/* -0.89218=f(2, 1.55)*/
{30, 0,123,__LINE__, 0xbffec363, 0x00000000, 0x40080000, 0x00000000, 0x3ff8cccc, 0xccccccd0},	/* -1.9227=f(3, 1.55)*/
{30, 0,123,__LINE__, 0xc01a33c0, 0x00000000, 0x40100000, 0x00000000, 0x3ff8cccc, 0xccccccd0},	/* -6.55054=f(4, 1.55)*/
{30, 0,123,__LINE__, 0x3fdae846, 0x20000000, 0x00000000, 0x00000000, 0x3ff99999, 0x9999999d},	/* 0.420427=f(0, 1.6)*/
{30, 0,123,__LINE__, 0xbfd63eb7, 0xc0000000, 0x3ff00000, 0x00000000, 0x3ff99999, 0x9999999d},	/* -0.347578=f(1, 1.6)*/
{30, 0,123,__LINE__, 0xbfeb5b55, 0xe0000000, 0x40000000, 0x00000000, 0x3ff99999, 0x9999999d},	/* -0.854899=f(2, 1.6)*/
{30, 0,123,__LINE__, 0xbffca27d, 0x60000000, 0x40080000, 0x00000000, 0x3ff99999, 0x9999999d},	/* -1.78967=f(3, 1.6)*/
{30, 0,123,__LINE__, 0xc0176cea, 0xc0000000, 0x40100000, 0x00000000, 0x3ff99999, 0x9999999d},	/* -5.85636=f(4, 1.6)*/
{30, 0,123,__LINE__, 0x3fdbf803, 0x80000000, 0x00000000, 0x00000000, 0x3ffa6666, 0x6666666a},	/* 0.437013=f(0, 1.65)*/
{30, 0,123,__LINE__, 0xbfd4381f, 0xe0000000, 0x3ff00000, 0x00000000, 0x3ffa6666, 0x6666666a},	/* -0.315926=f(1, 1.65)*/
{30, 0,123,__LINE__, 0xbfea3d0d, 0x60000000, 0x40000000, 0x00000000, 0x3ffa6666, 0x6666666a},	/* -0.819953=f(2, 1.65)*/
{30, 0,123,__LINE__, 0xbffabfd9, 0xc0000000, 0x40080000, 0x00000000, 0x3ffa6666, 0x6666666a},	/* -1.67184=f(3, 1.65)*/
{30, 0,123,__LINE__, 0xc01509b0, 0x00000000, 0x40100000, 0x00000000, 0x3ffa6666, 0x6666666a},	/* -5.25946=f(4, 1.65)*/
{30, 0,123,__LINE__, 0x3fdcee02, 0xa0000000, 0x00000000, 0x00000000, 0x3ffb3333, 0x33333337},	/* 0.452027=f(0, 1.7)*/
{30, 0,123,__LINE__, 0xbfd238f4, 0x60000000, 0x3ff00000, 0x00000000, 0x3ffb3333, 0x33333337},	/* -0.284726=f(1, 1.7)*/
{30, 0,123,__LINE__, 0xbfe92f18, 0xa0000000, 0x40000000, 0x00000000, 0x3ffb3333, 0x33333337},	/* -0.786999=f(2, 1.7)*/
{30, 0,123,__LINE__, 0xbff91294, 0x80000000, 0x40080000, 0x00000000, 0x3ffb3333, 0x33333337},	/* -1.56704=f(3, 1.7)*/
{30, 0,123,__LINE__, 0xc012f990, 0xe0000000, 0x40100000, 0x00000000, 0x3ffb3333, 0x33333337},	/* -4.74372=f(4, 1.7)*/
{30, 0,123,__LINE__, 0x3fddcaa1, 0xa0000000, 0x00000000, 0x00000000, 0x3ffc0000, 0x00000004},	/* 0.465493=f(0, 1.75)*/
{30, 0,123,__LINE__, 0xbfd04117, 0xe0000000, 0x3ff00000, 0x00000000, 0x3ffc0000, 0x00000004},	/* -0.253973=f(1, 1.75)*/
{30, 0,123,__LINE__, 0xbfe82f15, 0x40000000, 0x40000000, 0x00000000, 0x3ffc0000, 0x00000004},	/* -0.755747=f(2, 1.75)*/
{30, 0,123,__LINE__, 0xbff79340, 0x00000000, 0x40080000, 0x00000000, 0x3ffc0000, 0x00000004},	/* -1.47345=f(3, 1.75)*/
{30, 0,123,__LINE__, 0xc0112f2f, 0xa0000000, 0x40100000, 0x00000000, 0x3ffc0000, 0x00000004},	/* -4.29608=f(4, 1.75)*/
{30, 0,123,__LINE__, 0x3fde8e3d, 0xa0000000, 0x00000000, 0x00000000, 0x3ffccccc, 0xccccccd1},	/* 0.477432=f(0, 1.8)*/
{30, 0,123,__LINE__, 0xbfcca10d, 0x20000000, 0x3ff00000, 0x00000000, 0x3ffccccc, 0xccccccd1},	/* -0.223665=f(1, 1.8)*/
{30, 0,123,__LINE__, 0xbfe73af7, 0xc0000000, 0x40000000, 0x00000000, 0x3ffccccc, 0xccccccd1},	/* -0.725948=f(2, 1.8)*/
{30, 0,123,__LINE__, 0xbff63b9c, 0x60000000, 0x40080000, 0x00000000, 0x3ffccccc, 0xccccccd1},	/* -1.38955=f(3, 1.8)*/
{30, 0,123,__LINE__, 0xc00f3f46, 0xc0000000, 0x40100000, 0x00000000, 0x3ffccccc, 0xccccccd1},	/* -3.9059=f(4, 1.8)*/
{30, 0,123,__LINE__, 0x3fdf3934, 0xe0000000, 0x00000000, 0x00000000, 0x3ffd9999, 0x9999999e},	/* 0.487867=f(0, 1.85)*/
{30, 0,123,__LINE__, 0xbfc8cea3, 0xe0000000, 0x3ff00000, 0x00000000, 0x3ffd9999, 0x9999999e},	/* -0.193806=f(1, 1.85)*/
{30, 0,123,__LINE__, 0xbfe650fe, 0x20000000, 0x40000000, 0x00000000, 0x3ffd9999, 0x9999999e},	/* -0.697387=f(2, 1.85)*/
{30, 0,123,__LINE__, 0xbff50660, 0xc0000000, 0x40080000, 0x00000000, 0x3ffd9999, 0x9999999e},	/* -1.31406=f(3, 1.85)*/
{30, 0,123,__LINE__, 0xc00c83ee, 0xe0000000, 0x40100000, 0x00000000, 0x3ffd9999, 0x9999999e},	/* -3.56442=f(4, 1.85)*/
{30, 0,123,__LINE__, 0x3fdfcbe5, 0xe0000000, 0x00000000, 0x00000000, 0x3ffe6666, 0x6666666b},	/* 0.49682=f(0, 1.9)*/
{30, 0,123,__LINE__, 0xbfc50b3f, 0xa0000000, 0x3ff00000, 0x00000000, 0x3ffe6666, 0x6666666b},	/* -0.164406=f(1, 1.9)*/
{30, 0,123,__LINE__, 0xbfe56fa5, 0x60000000, 0x40000000, 0x00000000, 0x3ffe6666, 0x6666666b},	/* -0.669879=f(2, 1.9)*/
{30, 0,123,__LINE__, 0xbff3ef10, 0x40000000, 0x40080000, 0x00000000, 0x3ffe6666, 0x6666666b},	/* -1.24587=f(3, 1.9)*/
{30, 0,123,__LINE__, 0xc00a1d8e, 0xa0000000, 0x40100000, 0x00000000, 0x3ffe6666, 0x6666666b},	/* -3.26443=f(4, 1.9)*/
{30, 0,123,__LINE__, 0x3fe02359, 0x40000000, 0x00000000, 0x00000000, 0x3fff3333, 0x33333338},	/* 0.504315=f(0, 1.95)*/
{30, 0,123,__LINE__, 0xbfc15746, 0xc0000000, 0x3ff00000, 0x00000000, 0x3fff3333, 0x33333338},	/* -0.135476=f(1, 1.95)*/
{30, 0,123,__LINE__, 0xbfe4959f, 0xe0000000, 0x40000000, 0x00000000, 0x3fff3333, 0x33333338},	/* -0.643265=f(2, 1.95)*/
{30, 0,123,__LINE__, 0xbff2f1d5, 0x60000000, 0x40080000, 0x00000000, 0x3fff3333, 0x33333338},	/* -1.18404=f(3, 1.95)*/
{30, 0,123,__LINE__, 0xc007ffe0, 0x40000000, 0x40100000, 0x00000000, 0x3fff3333, 0x33333338},	/* -2.99994=f(4, 1.95)*/
{0},};
void test_ynf(m)   {run_vector_1(m,ynf_vec,(char *)(ynf),"ynf","fif");   }	
